@@ -21,7 +21,7 @@ our $CFG = {
 sub _build_sphinx_ver {
     my $self = shift;
 
-    return $self->cfg->{SPHINX}->{SPHINX_VER} || $PROC->{SPHINX}->{SPHINX_VER};
+    return $self->cfg->{SPHINX}->{SPHINX_VER} || $DIST->{SPHINX}->{SPHINX_VER};
 }
 
 # APP
